This function creates an Excel file with each dataframe in a list as a separate sheet.
Value
No return value. The function prints a message indicating the completion of the Excel file writing.
Examples
# \donttest{
tox_dat <- extr_comptox("50-00-0")
#> ℹ Checking Internet Connection...
#> ℹ Internet connection OK...
#> ℹ Sending request to CompTox...
#> ℹ Getting info from CompTox...
temp_file <- tempfile(fileext = ".xlsx")
write_dataframes_to_excel(tox_dat, filename = temp_file)
#> ℹ Excel file written in /tmp/Rtmp8sSn5D/file1f2cb1cf8263b.xlsx...
# }