This function searches for matches in a dataframe based on a given list of
ids and search type, then combines the results into a single dataframe,
making sure that NA rows are added for any missing ids. The column
query is a the end of the dataframe.
search_and_match(dat, ids, search_type, col_names, chemical_col = "chemical")A dataframe with search results.
The dataframe to be searched.
A vector of ids to search for.
The type of search: "casrn" or "name".
Column names to be used when creating a new dataframe in case of no matches.
The name of the column in dat where chemical names are stored.
This function is used in extr_pprtv and extr_monograph.
extr_pprtv, extr_monograph